"use client";

import { Link } from "@/i18n/routing";
import { useRouter } from "next/navigation";
import { useEffect } from "react";

export default function Error({
	error,
	reset,
}: {
	error: Error & { digest?: string };
	reset: () => void;
}) {
	const router = useRouter();

	useEffect(() => {
		// Log the error to an error reporting service
		console.error(error);
	}, [error]);

	return (
		<div className="min-h-screen flex items-center justify-center bg-gray-50">
			<div className="max-w-md w-full p-8 bg-white rounded-lg shadow-lg text-center">
				<h1 className="text-4xl font-bold text-red-600 mb-4">500</h1>
				<h2 className="text-2xl font-semibold text-gray-800 mb-4">Server Error</h2>
				<p className="text-gray-600 mb-8">
					We apologize, but something went wrong on our end. Please try again later.
				</p>
				<div className="flex flex-col sm:flex-row gap-4 justify-center">
					<button
						onClick={() => reset()}
						className="px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700 transition-colors"
					>
						Try Again
					</button>
					<Link
						href={"/" as any}
						className="px-4 py-2 bg-gray-200 text-gray-800 rounded-md hover:bg-gray-300 transition-colors"
					>
						Go to Homepage
					</Link>
				</div>
			</div>
		</div>
	);
} 